% Supplementary data to manuscript: Development of a country-wide seismic
% site-response zonation map for the Netherlands.

% Loads 3 .txt files (for each of the 3 geological models) and plots ite-response zonation map for the Netherlands.
%  in RD (Rijksdriehoek) coordinate system

% This script plots the three goelogical maps on top of each other:
% - NL3D as basis, 
% - on top GeoTOP where it is available
% - DGM is used at the locations with shallow (<100 m) hardrock

% Janneke van Ginkel, j.a.van.ginkel@rug.nl, August 2021

% NL3D
[Z,R] = arcgridread(fullfile(pwd,'files',['NL3Dclasses.txt'])); 

fsize=18;
dx=250;
dy=dx;
Xcenter=0; %NL
Ycenter=300000; %NL

nx=length(Z(1,:));    % number of rows
ny=length(Z(:,2));         % number of columns
xvec=[Xcenter:dx:Xcenter+((nx-1)*dx)];
yvec=[Ycenter:dy:Ycenter+((ny-1)*dy)];
figure(1)
pcolor(xvec/1000,yvec/1000,Z);
shading flat 
axis equal tight
set(gca,'FontSize',fsize);
    
cmap=[0.9853,    0.6084,    0.0242;... % class 1 
    0.9932,    0.9062,    0.1439;... % class 2
 0.2599,    0.7455,    0.4445;... % class 3
 0.2105,    0.3637,    0.5522;... %class 4
  0.8,0.8,0.8;...    % class 5
  0.2,0.2,0.2]; % Anthropogenic gray
colormap(cmap);

hold on

% GeoTOP
[Z,R] = arcgridread(fullfile(pwd,'files',['GeoTOPclasses.txt'])); 

dx=100;
dy=dx;
Xcenter=50; %NL
Ycenter=300050; %NL
nx=length(Z(1,:));    % number of rows
ny=length(Z(:,2));         % number of columns

xvec=[Xcenter:dx:Xcenter+((nx-1)*dx)];
yvec=[Ycenter:dy:Ycenter+((ny-1)*dy)];

figure(1);
colormap(cmap);
pcolor(xvec/1000,yvec/1000,Z);
shading flat 
axis equal tight
set(gca,'FontSize',fsize);
    
% DGM 

[Z,R] = arcgridread(fullfile(pwd,'files',['DGMclasses.txt'])); 

dx=250;
dy=dx;
XSlim=[10250 278000];
YSlim=[306750 626500];

xvec=XSlim(1):dx:XSlim(2);
yvec=YSlim(1):dy:YSlim(2);
nx=length(xvec);
ny=length(yvec);

figure(1)
colormap(cmap);
pcolor(xvec/1000,yvec/1000,Z);
shading flat 
axis equal tight
set(gca,'FontSize',fsize);
xlabel('RDx [km]')
ylabel('RDy [km]')


% Colorbar INCLUDING AF-values
%ch=colorbar('Location','EastOutside','FontSize',18,'Ticks',[1.41,2.24,3.07,3.9,4.73,5.56],'TickLabels',{'Class I \newlineno AF','Class II \newlineAF 1.94 \pm 0.33'...
    %,'Class III \newlineAF 2.40 \pm 0.28 ','Class IV \newlineAF 3.03 \pm 0.34','Class V \newlineAF not calibrated','Anthropogene \newlinedeposits >2m'});

    % Colorbar EXCLUDING AF
ch=colorbar('Location','EastOutside','FontSize',18,'Ticks',[1.41,2.24,3.07,3.9,4.73,5.56],'TickLabels',{'Class I ','Class II '...
    ,'Class III  ','Class IV ','Class V','Anthropogenic \newlinedeposits >2m'});
set(ch,'FontSize',fsize,'FontName','SansSerif');
set(gca,'FontName','SansSerif');
